@@ -57,7 +57,19 @@
     html_logo_url = "https://raw.githubusercontent.com/tiby312/broccoli/master/assets/logo.png",
     html_favicon_url = "https://raw.githubusercontent.com/tiby312/broccoli/master/assets/logo.png"
 )]
-//#![no_std]
+#![no_std]
+
+#[cfg(doctest)]
+mod test_readme {
+    macro_rules! external_doc_test {
+        ($x:expr) => {
+            #[doc = $x]
+            extern "C" {}
+        };
+    }
+
+    external_doc_test!(include_str!("../README.md"));
+}
 
 #[macro_use]
 extern crate alloc;
@@ -119,7 +131,7 @@ pub mod query {
     pub use queries::colfind::builder::CollisionHandler;
     pub use queries::colfind::builder::{NotSortedQueryBuilder, QueryBuilder};
     pub use queries::draw::DividerDrawer;
-    pub use queries::knearest::{KResult,Knearest, KnearestResult};
+    pub use queries::knearest::{KResult, Knearest, KnearestResult};
     pub use queries::nbody::GravEnum;
     pub use queries::nbody::Nbody;
     pub use queries::raycast::{CastAnswer, RayCast};
